package org.gcube.portlets.user.workspace.client.view.dialog;

import java.util.List;

import org.gcube.portlets.user.workspace.client.AppController;
import org.gcube.portlets.user.workspace.client.AppControllerExplorer;
import org.gcube.portlets.user.workspace.client.event.SettingPermissionEvent;
import org.gcube.portlets.user.workspace.client.model.FileModel;
import org.gcube.portlets.user.workspace.client.model.InfoContactModel;
import org.gcube.portlets.user.workspace.client.resources.Resources;
import org.gcube.portlets.user.workspace.client.view.sharing.PanelTogglePermission;
import org.gcube.portlets.user.workspace.client.view.windows.MessageBoxAlert;
import org.gcube.portlets.user.workspace.shared.WorkspaceACL;

import com.extjs.gxt.ui.client.Style.HorizontalAlignment;
import com.extjs.gxt.ui.client.Style.Scroll;
import com.extjs.gxt.ui.client.Style.VerticalAlignment;
import com.extjs.gxt.ui.client.event.ButtonEvent;
import com.extjs.gxt.ui.client.event.SelectionListener;
import com.extjs.gxt.ui.client.widget.Dialog;
import com.extjs.gxt.ui.client.widget.HorizontalPanel;
import com.extjs.gxt.ui.client.widget.layout.FormLayout;
import com.google.gwt.core.shared.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Label;

/**
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * 
 */
public class DialogPermission extends Dialog {

	private int widthDialog = 400;
	private FileModel parentFolder = null;

	private PanelTogglePermission permission;
	private HorizontalPanel hpPermission = new HorizontalPanel();
	private FileModel folder;

	private DialogPermission INSTANCE = this;
	
	public FileModel getParentFolder() {
		return parentFolder;
	}

	public void initLayout(String folderParentName) {
		FormLayout layout = new FormLayout();
		layout.setLabelWidth(90);
		layout.setDefaultWidth(380);
		setLayout(layout);
		setModal(true);
		setScrollMode(Scroll.AUTOY);
		setBodyStyle("padding: 9px; background: none");
		setWidth(widthDialog);
		setHeight(140);
		setResizable(true);
		setButtonAlign(HorizontalAlignment.CENTER);
		setWidth(widthDialog);
		setButtons(Dialog.OKCANCEL);
	}

	/**
	 * Use to set permission to VRE Folder
	 */
	public DialogPermission(FileModel folder) {

		this.folder = folder;
		
		Label labelProperty = new Label("Permissions");

		hpPermission.add(labelProperty);
		hpPermission.setVerticalAlign(VerticalAlignment.MIDDLE);
		hpPermission.mask("Checking authorization");
		
		
		AsyncCallback<InfoContactModel> callcack = new AsyncCallback<InfoContactModel>() {

			@Override
			public void onFailure(Throwable caught) {
				new MessageBoxAlert("Alert", "Sorry, an error occurred on recovering ACLs",null);
				hpPermission.unmask();
			}

			@Override
			public void onSuccess(InfoContactModel result) {
				 permissionControl(result.getLogin(), true);
				 hpPermission.unmask();
			}
		};
		
		getOwner(folder.getIdentifier(), callcack);

		//TODO GET ACL FOR USER
		AppControllerExplorer.rpcWorkspaceService.getACLs(new AsyncCallback<List<WorkspaceACL>>() {

			@Override
			public void onSuccess(List<WorkspaceACL> result) {
				permission = new PanelTogglePermission(result);
				hpPermission.add(permission);
				hpPermission.layout();
				layout();
			}

			@Override
			public void onFailure(Throwable caught) {
				new MessageBoxAlert("Alert", "Sorry, an error occurred on recovering ACLs",null);
			}
		});

		initLayout(folder.getName());
		this.setIcon(Resources.getIconVREFolder());
		setHeading("Change permissions to folder: " + folder.getName());

		setWidth(widthDialog);
		setButtons(Dialog.OKCANCEL);

		add(hpPermission);
		addListners();
		getButtonById(Dialog.OK).setEnabled(false);
		enableFormDialog(false);
	}

	public void addListners() {

		this.getButtonById(Dialog.CANCEL).addSelectionListener(
			new SelectionListener<ButtonEvent>() {

				@Override
				public void componentSelected(ButtonEvent ce) {
					hide();
				}
		});

		this.getButtonById(Dialog.OK).addSelectionListener(
			new SelectionListener<ButtonEvent>() {
	
				@Override
				public void componentSelected(ButtonEvent ce) {
						
					AppController.getEventBus().fireEvent(new SettingPermissionEvent(folder, INSTANCE));
//						hide();
				}
		});

	}
	
	
	private void permissionControl(String owner, boolean showAlert){
		GWT.log("DialogPermission control compare between owner: "+owner +" and my login: "+AppControllerExplorer.myLogin);
		if(AppControllerExplorer.myLogin.compareToIgnoreCase(owner)!=0){
			enableFormDialog(false);
			if(showAlert)
				new MessageBoxAlert("Permission denied", "You have no permissions to change sharing. You are not owner of \""+folder.getName()+"\"", null);
		}else{
			enableFormDialog(true);
		}
	}
	
	private void enableFormDialog(boolean bool){
		 getButtonById(Dialog.OK).setEnabled(bool);
		 
		 if(permission!=null)
			 permission.setEnabled(bool); 
	}
	
	public void getOwner(final String sharedFolderId,final AsyncCallback<InfoContactModel> callback) {
		
		AppControllerExplorer.rpcWorkspaceService.getOwnerByItemId(sharedFolderId, new AsyncCallback<InfoContactModel>() {

			@Override
			public void onFailure(Throwable caught) {
				GWT.log("an error occured in get Owner by Id "+sharedFolderId + " "+caught.getMessage());
				new MessageBoxAlert("Alert", "Sorry, an error occurred on owner property",null);
				
			}

			@Override
			public void onSuccess(InfoContactModel result) {
				callback.onSuccess(result);
				
			}
		});
	}
	
	public WorkspaceACL getSelectedACL(){
		if(permission!=null)
			return permission.getSelectedACL();
		
		return null;
	}
}
